@@ -38,6 +38,7 @@ use 5.012;
 
 use Data::Dumper;
 use Date::Format;
+use Params::Validate qw( :all );
 
 =head1 NAME
 
@@ -69,16 +70,18 @@ This module provides the following public functions:
 
 =over 
 
-=item C<utc_timestamp>
-
 =item C<is_directory_viable>
 
+=item C<stringify_args>
+
+=item C<utc_timestamp>
+
 =back
 
 =cut 
 
 use Exporter qw( import );
-our @EXPORT_OK = qw( utc_timestamp is_directory_viable stringify_args );
+our @EXPORT_OK = qw( is_directory_viable stringify_args utc_timestamp );
 
 
 
@@ -93,15 +96,6 @@ our $not_viable_reason = '';
 =head1 FUNCTIONS
 
 
-=head2 utc_timestamp
-
-=cut
-
-sub utc_timestamp {
-   return uc time2str("%Y-%m-%d %H:%M %Z", time, 'GMT');
-}
-
-
 =head2 is_directory_viable
 
 Run viability checks on a directory. Takes: full path to directory. Returns
@@ -160,5 +154,15 @@ sub stringify_args {
     return $args_as_string;
 }
 
+
+=head2 utc_timestamp
+
+=cut
+
+sub utc_timestamp {
+   return uc time2str("%Y-%m-%d %H:%M %Z", time, 'GMT');
+}
+
+
 # END OF App::CELL::Util.pm
 1;
